Extract a fitted MRF
Usage
get_mrf(object, ...)
# S3 method for class 'bam'
get_mrf(object, ...)
# S3 method for class 'gamm'
get_mrf(object, ...)
# S3 method for class 'gamm4'
get_mrf(object, ...)
# S3 method for class 'gam'
get_mrf(object, term, ...)Arguments
- object
An object from which to extract the fitted MRF. Currently only for objects of classes
gam,bam, andgamm, and GAMMs fitted bygamm4::gamm4().- ...
Arguments passed to other methods.
- term
character; the MRF term to extract. Can be a partial match to a term, which is matched against the smooth label.